version 8
clear
set matsize 180
set logtype text
set mem 800m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture log close
log using "brazempl/logs/cnae-niv50.log", replace

local yr 96
use "rais-sp/raisraw/cnae/cnae`yr'", replace
rename cnae cnae`yr'
forvalues yr = 97/98 {
  sort firmid plantid
  merge firmid plantid using "rais-sp/raisraw/cnae/cnae`yr'"
  rename cnae cnae`yr'
  drop _m
  }
forvalues yr = 96/98 {
  rename cnae`yr' s_cnae`yr'
  gen int cnae`yr' = int(real(s_cnae`yr'))
  label var cnae`yr' "Sector (CNAE) 19`yr'"
  }
drop s_*
replace cnae97 = cnae96 if cnae97==.
replace cnae97 = cnae98 if cnae97==.
drop cnae96 cnae98
rename cnae97 cnae
* duplicates drop
sort cnae
merge cnae using "brazcomp/filters/cnae-niv-naic", nokeep
tab _m
keep if _m==3
rename niv niv100

* assign mode niv50 (across plants) to firm; if no mode, randomly assign (and keep according random niv100)
keep firmid plantid niv100
gen niv50 = int(niv100/100)
sort firmid
by firmid: egen _maxniv = max(niv50)
by firmid: egen _minniv = min(niv50)
gen byte indconfl = (_maxniv ~= _minniv)
label var indconfl "Indic.: Conflicting sector info"
sort firmid plantid
by firmid: egen _oneniv = mode(niv50)
gen _rndmnr = uniform()
sort firmid _rndmnr
by firmid: replace _oneniv = niv50 if _n==1 & _oneniv==.
drop if _oneniv==.
replace niv50 = _oneniv
keep firmid niv50 niv100 indconfl
duplicates drop
sort firmid
compress
save "brazempl/data/firms-niv50", replace

log close
cd "$home"
