version 8
clear
set matsize 180
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

/* Load variable names and save for est2tex */

insheet using "brazempl/tex/regrossor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "brazempl/tex/v1/tables/infpnad_rowlbl", replace
save "brazempl/tex/v1/tables/emplpnad_rowlbl", replace
save "brazempl/tex/v1/tables/secpnad_rowlbl", replace
save "brazempl/tex/v1/tables/forminform_rowlbl", replace
save "brazempl/tex/v1/tables/lnwagepnad1_rowlbl", replace
save "brazempl/tex/v1/tables/lnwagepnad2_rowlbl", replace
save "brazempl/tex/v1/tables/premiapnad_rowlbl", replace
clear


/* Load PNAD informality shares */

insheet using "brazempl/auxil/pnad-emprego.csv", clear
mat infpnad = J(2,5,-999)
forvalues colj = 1/5 {
  local varj = `colj' + 1
  mat infpnad[1,`colj'] = real(subinstr(v`varj'[17],",","",.))/real(subinstr(v`varj'[5],",","",.))
  mat infpnad[2,`colj'] = real(subinstr(v`varj'[19],",","",.))/real(subinstr(v`varj'[7],",","",.))
  }
matname infpnad agric comm manuf servcs total, columns(1..5) explicit
matname infpnad infshare_pnad:1990 infshare_pnad:1997, rows(1..2) explicit
drop _all


/* Load RAIS results */

matload lnwmeanshr_tbl, path(brazempl/tex/v1/tables) over
* Deflate year 1997 with log US CPI .187
foreach rowi in 7 8 9 10 11 12 14 { 
  forvalues colj = 1/4 {
    mat lnwmeanshr_tbl[`rowi',`colj'] = lnwmeanshr_tbl[`rowi',`colj'] - .187
    }
  }
mat rais = lnwmeanshr_tbl[13..14,3] \ lnwmeanshr_tbl[1..12,3]  /* manufacturing wages only; sector info first */
mat rownames rais = rais
mat raisempl = lnwmeanshr_tbl[1,5..8] \ lnwmeanshr_tbl[7,5..8] \ lnwmeanshr_tbl[3,5..8] \ lnwmeanshr_tbl[9,5..8] \ lnwmeanshr_tbl[5,5..8] \ lnwmeanshr_tbl[11,5..8]  /* within sector info; all sectors */
mat rownames raisempl = rais
mat raissec = lnwmeanshr_tbl[13..14,5..8] /* across sector info; all sectors */
mat roweq raissec = rais 
mat raislnwage = lnwmeanshr_tbl[13..14,1..4] \ lnwmeanshr_tbl[1..2,1..4] \ lnwmeanshr_tbl[7..8,1..4] \ lnwmeanshr_tbl[3..4,1..4] \ lnwmeanshr_tbl[9..10,1..4] \ lnwmeanshr_tbl[5..6,1..4] \ lnwmeanshr_tbl[11..12,1..4]
mat drop lnwmeanshr_tbl


/* Load PNAD for log wages */

local rownames : rowfullnames raislnwage
disp "`rownames'"
foreach mat in 1 2 {
  mat lnwagepnad`mat' = J(14,6,-999)
  matname lnwagepnad`mat' `rownames', rows(1..14) explicit
  matname lnwagepnad`mat' rais pnadform pnadinf rais pnadform pnadinf, columns(1..6) explicit
  }
mat coleq lnwagepnad1 = agric agric agric comm comm comm
mat coleq lnwagepnad2 = manuf manuf manuf servcs servcs servcs
local count = -1
foreach column in formal informal {
local count = `count' + 1
insheet using "brazempl/auxil/pnad-`column'.csv", clear
keep if v1~=v9 /* remove empty lines */
keep v1 v2-v5 /* wages, all sectors */
rename v1 var
gen str eq = var if v2=="" & v3=="" & v4=="" & v5==""
replace eq = eq[_n-1] if eq==""
replace eq = trim(eq)
replace var = trim(var)
drop if eq=="" | var==""
qui compress
order eq
drop if v2=="" & v3=="" & v4=="" & v5==""
forvalues varj = 2/5 {
  rename v`varj' _v`varj'
  gen v`varj' = real(_v`varj')
  drop _v`varj'
  * INPC-12/90: 1001.9506 / INPC-9/90: 628.5792 = 1.5940
  * BCR/USD-12/90: 170.06 / BCR/USD-9/90: 84.223 = 2.0192
  * Correction term 1990 (add to PNAD): log((1/2.0192)*1.5940) < 0
  replace v`varj' = v`varj' + log((1/2.0192)*1.5940) if eq=="1990" | var=="1990"
  * INPC-12/97: 26638626 / INPC-9/97: 26371590 = 1.0101
  * BRL/USD-12/90: 1.1149 / BRL/USD-9/90: 1.0954 = 1.0178
  * Correction term 1997 (add to PNAD): log((1/1.0178)*1.0101) < 0
  replace v`varj' = v`varj' + log((1/1.0178)*1.0101) if eq=="1997" | var=="1997"
  }
forvalues rowi = 1/14 {
  mat lnwagepnad1[`rowi',2+`count'] = v2[`rowi'] /* Agriculture */
  mat lnwagepnad1[`rowi',5+`count'] = v3[`rowi'] /* Commerce */
  mat lnwagepnad2[`rowi',2+`count'] = v4[`rowi'] /* Manufacturing */
  mat lnwagepnad2[`rowi',5+`count'] = v5[`rowi'] /* Services */
  }
}
forvalues mat = 1/2 {
  forvalues sec = 1/2 {
    local raiscol = `mat'*2 -1 + (`sec'-1)
    local colj = (`sec'-1)*3 + 1
    forvalues rowi = 1/14 {
      mat lnwagepnad`mat'[`rowi',`colj'] = raislnwage[`rowi',`raiscol']
      }
    }
  }


/* Load PNAD for employment shares */

mat emplpnad = J(6,8,-999)
matname emplpnad malefem:1990 malefem:1997 collhigh:1990 collhigh:1997 whitblue:1990 whitblue:1997, rows(1..6) explicit
matname emplpnad f:agric f:comm f:manuf f:servcs inf:agric inf:comm inf:manuf inf:servcs, columns(1..8) explicit

local mincol = -4
foreach column in formal informal {
local mincol = `mincol' + 4
insheet using "brazempl/auxil/pnad-`column'.csv", clear
keep if v1~=v9 /* remove empty lines */
keep v1 v6-v9 /* employment shares, all sectors */
rename v1 var
drop in 2/5 /* drop sector decomp */
drop if var=="Mulher" | var=="at 11" | var=="Blue-collar"
drop if var=="1990" | var=="1997"
forvalues i = 2/7 {
  local row = `i' - 1
  forvalues j = 6/9 {
    local col = `j' - 5 + `mincol'
    mat emplpnad[`row',`col'] = real(v`j'[`i'])
    }
  }
}
mat emplpnad = raisempl , J(6,4,-999) \ emplpnad
* rearrange sectors
mat emplpnad = emplpnad[1..12,1] , emplpnad[1..12,5] , emplpnad[1..12,2] , emplpnad[1..12,6] , emplpnad[1..12,3] , emplpnad[1..12,7] , emplpnad[1..12,4] , emplpnad[1..12,8]
matname emplpnad f:agric inf:agric f:comm inf:comm f:manuf inf:manuf f:servcs inf:servcs, columns(1..8) explicit
* rearrange years
mat emplpnad = emplpnad[1,1..8] \ emplpnad[7,1..8] \ emplpnad[2,1..8] \ emplpnad[8,1..8] \ emplpnad[3,1..8] \ emplpnad[9,1..8] \ emplpnad[4,1..8] \ emplpnad[10,1..8] \ emplpnad[5,1..8] \ emplpnad[11,1..8] \ emplpnad[6,1..8] \ emplpnad[12,1..8]


/* Load PNAD for sector allocation */

mat secpnad = J(4,4,-999)
matname secpnad pnad_formal:1990 pnad_formal:1997 pnad_informal:1990 pnad_informal:1997, rows(1..4) explicit
matname secpnad agric comm manuf servcs, columns(1..4) explicit

local strtrow = - 1
foreach column in formal informal {
local strtrow = `strtrow' + 1
insheet using "brazempl/auxil/pnad-`column'.csv", clear
keep if v1~=v9 /* remove empty lines */
keep v1 v6-v9 /* employment shares, all sectors */
rename v1 var
keep in 1/5 /* keep sector decomp */
forvalues i = 4/5 {
  local row = `i' - 3 + 2*`strtrow'
  forvalues j = 6/9 {
    local col = `j' - 5 
    mat secpnad[`row',`col'] = real(v`j'[`i'])
    }
  }
}
mat secpnad = raissec \ secpnad
mat secpnad = secpnad[1,1..4] \ secpnad[3,1..4] \ secpnad[5,1..4] \ secpnad[2,1..4] \ secpnad[4,1..4] \ secpnad[6,1..4]
matname secpnad agric comm manuf servcs, columns(1..4) explicit

mat forminform = infpnad \ (secpnad , J(6,1,1) )


/* Load PNAD for wage differentials */

mat premiapnad = J(7,4,-999)
matname premiapnad time:1997_1990_all malefem:1990_all malefem:1997_all collhigh:1990_all collhigh:1997_all whitblue:1990_all whitblue:1997_all, rows(1..7) explicit
matname premiapnad pnad_total pnad_formal pnad_informal rais_uncond, columns(1..4) explicit

local col = 0
foreach column in total formal informal {
local col = `col' + 1
insheet using "brazempl/auxil/pnad-`column'.csv", clear
keep if v1~=v9 /* remove empty lines */
keep v1 v2-v5 /* wages, all sectors */
rename v1 var
gen str eq = var if v2=="" & v3=="" & v4=="" & v5==""
replace eq = eq[_n-1] if eq==""
replace eq = trim(eq)
replace var = trim(var)
drop if eq=="" | var==""
qui compress
order eq
drop if v2=="" & v3=="" & v4=="" & v5==""
forvalues varj = 2/5 {
  rename v`varj' _v`varj'
  gen v`varj' = real(_v`varj')
  drop _v`varj'
  * INPC-12/90: 1001.9506 / INPC-9/90: 628.5792 = 1.5940
  * BCR/USD-12/90: 170.06 / BCR/USD-9/90: 84.223 = 2.0192
  * Correction term 1990 (add to PNAD): log((1/2.0192)*1.5940) < 0
  replace v`varj' = v`varj' + log((1/2.0192)*1.5940) if eq=="1990" | var=="1990"
  * INPC-12/97: 26638626 / INPC-9/97: 26371590 = 1.0101
  * BRL/USD-12/90: 1.1149 / BRL/USD-9/90: 1.0954 = 1.0178
  * Correction term 1997 (add to PNAD): log((1/1.0178)*1.0101) < 0
  replace v`varj' = v`varj' + log((1/1.0178)*1.0101) if eq=="1997" | var=="1997"
  }
keep var v4 /* manufacturing only */
foreach row in 1 {
  local line2 = `row'*2
  local line1 = `line2' - 1
  mat premiapnad[`row',`col'] = exp(v4[`line2'])/exp(v4[`line1'])
  }
foreach row in 2 3 4 5 6 7 {
  local line2 = `row'*2
  local line1 = `line2' - 1
  mat premiapnad[`row',`col'] = exp(v4[`line1'])/exp(v4[`line2'])
  }
}

* Add RAIS (rais rows need to be rearranged to: time:1997_1990_all malefem:1990_all malefem:1997_all collhigh:1990_all collhigh:1997_all whitblue:1990_all whitblue:1997_all)
* rearrange RAIS table in Naercio style
mat rais = rais[1..2,1] \ rais[3..4,1] \ rais[9..10,1] \ rais[5..6,1] \ rais[11..12,1] \ rais[7..8,1] \ rais[13..14,1]
mat premiapnad[1,4] = exp(rais[2,1])/exp(rais[1,1])
forvalues row = 2/7 {
  local line2 = `row'*2
  local line1 = `line2' - 1
  mat premiapnad[`row',4] = exp(rais[`line1',1])/exp(rais[`line2',1])
  }
mat premiapnad = premiapnad[1..7,4], premiapnad[1..7,1..3]


/* Output Tables */

foreach mat in infpnad lnwagepnad1 lnwagepnad2 emplpnad secpnad forminform premiapnad {
  mat rename `mat' `mat'_tbl
  }
est2tex infpnad, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
est2tex emplpnad, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(2 4 6)
est2tex lnwagepnad1, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(3)
est2tex lnwagepnad2, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(3)
est2tex secpnad, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
est2tex forminform, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
est2tex premiapnad, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(1)
