version 8
clear
set matsize 180
set logtype text
set mem 900m
capture set mem 950m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

/* Exchange Rate File (identical to "brazdspl/%stata/%0ext-prep/prep-auxil.do") */
local country = "brazil"
tempfile `country'
local i 0
foreach file in "auxil/__brl_d" {
    local i = `i' + 1
    local series = substr("`file'",-index(reverse("`file'"),"/")+1,index(reverse("`file'"),"/")-1)
    insheet using "brazdspl/`file'.csv", comma names clear
    keep date close
    gen day = date(date,"mdy")
    format day %d
    order day
    sort day
    drop if day==. & trim(lower(substr(date,1,12)))~="description:"
    local descrpt = date[_N]
    drop date
    drop if day==.
    local descrpt = trim(subinstr(substr("`descrpt'",index("`descrpt'"," - "),.),"- ","",.))
    label var day "Day"
    rename close `series'
    label var `series' "`descrpt'"
    sort day
    if `i'~=1 {
        merge day using ``country''
        drop _m
        }
    sort day
    compress
    save ``country'', replace
}
preserve
  keep if month(day)==9 & year(day)==1990  /* September 1990 */
  sort day
  local usdsep90 = __brl_d[_N]
  * disp "`usdsep90'"
restore, preserve
  keep if month(day)==9 & year(day)==1997  /* September 1997 */
  sort day
  local usdsep97 = __brl_d[_N]
  * disp "`usdsep97'"
restore

/* Label definitions (identical to "brazdspl/%stata/%2rais-prepare/recode-rais.do") */
capture program drop lbldef
program define lbldef
  capture label drop _all
  label define sector 1 "Agriculture" 2 "Commerce" 3 "Construction" 4 "Manufacturing" 5 "Services" 9 "Other"  
  label define month 0 "(not applicable)" 1 "January" 2 "February" 3 "March" 4 "April" 5 "May" 6 "June" 7 "July" 8 "August" 9 "September" 10 "October" 11 "November" 12 "December" 13 "(not applicable)"
  label define gender 0 "male" 1 "female"
  label define agerange 1 "10-14" 2 "15-17" 3 "18-24" 4 "25-29" 5 "30-39" 6 "40-49" 7 "50-64" 8 "65-"
  label define typeemp 1 "Private-sector Labor Contract (CLT)" 2 "Public-sector Contract" 3 "Free-lance Contract" 4 "Temporary Contract" 9 "Other Contract (incl. exec. management)"
  label define causedis 0 "(not laid off)" 1 "Retirement (or military discharge)" 2 "Conclusion of contract" 3 "Layoff (due to misconduct)" 4 "Layoff (economic cause)" 5 "Quit (due to misconduct)" 6 "Quit (economic cause)" 7 "Transfer or Move" 8 "Death" 9 "Other"
  label define national 1 "Brazilian Citizen" 2 "Citizen of industrialized country" 3 "Citizen of other Latin American country" 4 "Citizen of Other country"
  label define educ 1 "Illiterate" 2 "Primary School Dropout" 3 "Primary School Graduate" 4 "Middle School Dropout" 5 "Middle School Graduate" 6 "High School Dropout" 7 "High School Graduate" 8 "College Dropout" 9 "College Graduate"
  label define typeest 1 "CNPJ" 2 "CEI" 
  label define typehire 0 "(not newly hired)" 1 "Reemployment" 2 "First Employment" 3 "Transfer" 9 "Other"
  qui do "$root/rais/cbo/cbotrans.do"
  qui do "$root/rais/cbo/isco.do"
  * label define brsetor 1 "Agropecuaria" 2 "Comercio" 3 "Construcao" 4 "Industria" 5 "Servico" 9 "Outros"
  * label define brmes 0 "(nao applicavel)" 1 "Janeiro" 2 "Fevereiro" 3 "Marco" 4 "Abril" 5 "Maio" 6 "Junho" 7 "Julho" 8 "Agosto" 9 "Setembro" 10 "Outubro" 11 "Novembro" 12 "Decembro" 13 "(nao applicavel)"
  * label define brsexo 0 "masculino" 1 "feminino"
  * label define bridade 1 "10-14" 2 "15-17" 3 "18-24" 4 "25-29" 5 "30-39" 6 "40-49" 7 "50-64" 8 "65-"
  * label define brnatvinc 1 "Consolidao das Leis Trabalhistas" 2 "Estatutario" 3 "Trabalhador Avulso" 4 "Trabalhador Temporario" 9 "Outro"
  * label define brcausades 0 "(nao desligado)" 1 "Aposentadoria (ou reforma de militar)" 2 "Termino de contrato" 3 "Demissao (com justa causa)" 4 "Demissao (sem justa causa)" 5 "Rescisao, iniciativa do empregado (com justa causa)" 6 "Rescisao, iniciativa do empregado (sem justa causa)" 7 "Transferencia (ou movimentacao)" 8 "Falecimento" 9 "Outros"
  * label define brnacion 1 "Cidadao brasileiro" 2 "Cidadao de pais industrializado" 3 "Cidadao de pais da America Latina" 4 "Cidadao de outro pais"
  * label define breduc 1 "Analfabeto" 2 "Primario Incompleto" 3 "Primario Incompleto" 4 "Ginasio Incompleto" 5 "Ginasio Completo" 6 "Colegial Incompleto" 7 "Colegial Completo" 8 "Superior Incompleto" 9 "Superior Completo"
  * label define brtipoest 1 "CNPJ" 2 "CEI" 
  * label define brtipoadm 0 "(nao admitido)" 1 "Reemprego" 2 "Primeiro Emprego" 3 "Transferencia" 9 "Outro"
  * qui do "$root/rais/cbo/cbo.do"
  * qui do "$root/rais/cbo/isco.do"
end

foreach yr in 90 97 {

use "brazempl/pnad/pnad`yr'.dta", clear
drop year peso
lbldef

/* PREPARATIONS */
/*--------------*/

* Formal/informal
if `yr'==90 {
  replace ct=0 if ct==4
  replace ct=1 if ct==2
  gen byte indinfrm = (ct==0)
  }
if `yr'==97 {
  gen byte indinfrm = (ct==0)
  }  
label var indinfrm "Informal Employment"

* Generate variables conformable to RAIS
gen workerid = _n
gen byte year = `yr'
foreach var in schoolng gender age lnwage hourseff occupnad sector {
  gen byte `var' = .
  }
label var workerid  "Running Worker ID"
label var year      "Calendar Year"
label var schoolng  "Level of Schooling"
label var gender    "Gender"
label var age       "Age Range"
label var lnwage    "Log Ann. Wage equiv. (curr. USD)"
label var hourseff  "Effective Work Hours/Week"
label var occupnad  "Occupation Code (PNAD)"
label var sector    "Sector"
label values sector sector
label values gender gender
label values age agerange
label values schoolng educ
order workerid year schoolng gender age lnwage hourseff occupnad sector

* Conform educational categories
replace schoolng = 1 if educa==0                /* Illiterate */
replace schoolng = 2 if educa<4   & schoolng==. /* Primary School Dropout */
replace schoolng = 3 if educa==4  & schoolng==. /* Primary School Graduate */
replace schoolng = 4 if educa<8   & schoolng==. /* Middle School Dropout */
replace schoolng = 5 if educa==8  & schoolng==. /* Middle School Graduate */
replace schoolng = 6 if educa<12  & schoolng==. /* High School Dropout */
replace schoolng = 7 if educa==12 & schoolng==. /* High School Graduate */
replace schoolng = 8 if educa<16  & schoolng==. /* College Dropout */
replace schoolng = 9 if educa>=16 & schoolng==. /* College Graduate */
count if schoolng==. & educa~=.
if `r(N)' {
  disp as err "Incomplete education categorization"
  STOP
  }
drop educa

* Conform gender
replace gender = 0 if sexo==1
replace gender = 1 if sexo==0
count if gender==. & sexo~=.
if `r(N)' {
  disp as err "Incomplete gender categorization"
  STOP
  }
drop sexo

* Conform age groups
replace age = 1 if idade<=14          /* Child (10-14) */
replace age = 2 if idade<=17 & age==. /* Youth (15-17) */
replace age = 3 if idade<=24 & age==. /* Adolescent (18-24) */
replace age = 4 if idade<=29 & age==. /* Nascent Career (25-29) */
replace age = 5 if idade<=39 & age==. /* Early Career (30-39) */
replace age = 6 if idade<=49 & age==. /* Peak Career (40-49) */
replace age = 7 if idade<=64 & age==. /* Late Career (50-64) */
replace age = 8 if idade>64  & age==. /* Post Retirement (65-) */
count if age==. & idade~=.
if `r(N)' {
  disp as err "Incomplete age categorization"
  STOP
  }
drop idade

* Sector definition
replace sector = 4
keep if setor>=100 & setor<=300
drop setor

* Occupational definition: Blue and white-collar distinction
gen byte indblue = 1 if prod==1
replace  indblue = 0 if prod==0
label var indblue "Blue-collar occupation"
count if indblue==. & prod~=.
if `r(N)' {
  disp as err "Incomplete occupational categorization"
  STOP
  }
drop prod

* Working hours
replace hourseff = horas
drop horas

* Wages
if `yr'==90 {
  gen septwage = renda * 12 / `usdsep90'
  * INPC-12/90: 1001.9506 / INPC-9/90: 628.5792 = 1.5940
  * BCR/USD-12/90: 170.06 / BCR/USD-9/90: 84.223 = 2.0192
  * Correction term 1990 (add to PNAD): log((1/2.0192)*1.5940) < 0
  replace lnwage = log(septwage) + log((1/2.0192)*1.5940)
  }
if `yr'==97 { 
  gen septwage = renda * 12 / `usdsep97'
  * INPC-12/97: 26638626 / INPC-9/97: 26371590 = 1.0101
  * BRL/USD-12/90: 1.1149 / BRL/USD-9/90: 1.0954 = 1.0178
  * Correction term 1997 (add to PNAD): log((1/1.0178)*1.0101) < 0
  replace lnwage = log(septwage) + log((1/1.0178)*1.0101)
}


/* CONFORMABLE VARIABLE CREATION */
* (identical to "brazempl/%stata/%1prep-data/repl-data.do")

  * tab age
  gen workrage = 12 if age==1
  replace workrage =   16 if age==2
  replace workrage =   21 if age==3
  replace workrage =   27 if age==4
  replace workrage = 34.5 if age==5
  replace workrage = 44.5 if age==6
  label var workrage "Mid-point Age of Worker in Age Group"
  gen potexper     = workrage -  6 if school==1
  replace potexper = workrage -  7 if school==2
  replace potexper = workrage - 10 if school==3
  replace potexper = workrage - 11 if school==4
  replace potexper = workrage - 14 if school==5
  replace potexper = workrage - 15 if school==6
  replace potexper = workrage - 18 if school==7
  replace potexper = workrage - 19 if school==8
  replace potexper = workrage - 22 if school==9
  label var potexper "Potential Labor Force Experience"
  drop workrage
  gen potxper2 = potexper*potexper
  label var potxper2 "Quadratic Experience Term"
  gen potxper3 = potxper2*potexper
  label var potxper3 "Cubic Experience Term"
  gen potxper4 = potxper3*potexper
  label var potxper4 "Quartic Experience Term"
  gen byte indchild = (age==1)
  label var indchild "Child (10-14y.)"
  gen byte indyouth = (age==2)
  label var indyouth "Youth (15-17y.)"
  gen byte indadol = (age==3)
  label var indadol "Adolescent (18-24y.)"
  gen byte indnasc = (age==4)
  label var indnasc "Nascent Career (25-29y.)"
  gen byte indearly = (age==5)
  label var indearly "Early Career (30-39y.)"
  gen byte indpeak = (age==6)
  label var indpeak  "Peak Career (40-49y.)"
  gen byte indlate = (age==7)
  label var indlate  "Late Career (50-64y.)"
  gen byte indretir = (age==8)
  label var indretir "Post Retirement Age (65y.-)"
  qui tab schoolng, gen(indschlg)
  forvalues schllvl = 1/9 {
    local lbl : label educ `schllvl'
    label var indschlg`schllvl' "`lbl'"
    }
  gen byte indprim = (school==1 | school==2 | school==3 | school==4 | school==5)
  label var indprim "Primary or Middle School Educ."
  gen byte indhigh = (school==6 | school==7)
  label var indhigh "High School Education"
  gen byte indprim_alt = (school==1 | school==2 | school==3)
  label var indprim_alt "Primary School Education"
  gen byte indhigh_alt = (school==4 | school==5 | school==6 | school==7)
  label var indhigh_alt "Middle or High School Education"
  gen byte indscoll = (school==8)
  label var indscoll "Some College Education"
  gen byte indgrad = (school==9)
  label var indgrad "Complete College Education"
  drop schoolng
  gen byte indfem = (gender==1)
  label var indfem "Female"
  drop gender
  compress
  sort worker

  drop indchild indyouth indadol indnasc indearly indpeak indlate indretir 
  keep workerid year indinfrm age lnwage potexper potxper2 potxper3 potxper4 indschlg* indprim indhigh indprim_alt indhigh_alt indscoll indgrad indblue indfem sector
  order workerid year indinfrm age lnwage potexper potxper2 potxper3 potxper4 indschlg* indprim indhigh indprim_alt indhigh_alt indscoll indgrad indblue indfem sector
  sort workerid year
  compress

save "brazempl/pnad/use-pnad-`yr'", replace

}
