version 8
clear
set matsize 180
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

/* Load variable names and save for est2tex */

insheet using "brazempl/tex/regressor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "brazempl/tex/v1/tables/infpnad_rowlbl", replace
save "brazempl/tex/v1/tables/emplpnad_rowlbl", replace
save "brazempl/tex/v1/tables/secpnad_rowlbl", replace
save "brazempl/tex/v1/tables/forminform_rowlbl", replace
save "brazempl/tex/v1/tables/lnwmeanshr_pnad_rowlbl", replace
save "brazempl/tex/v1/tables/lnwagepnad1_rowlbl", replace
save "brazempl/tex/v1/tables/lnwagepnad2_rowlbl", replace
save "brazempl/tex/v1/tables/premiapnad_rowlbl", replace
clear


/* Load PNAD informality shares */

* infpnad in old sector sequence 1 2 4 5
insheet using "brazempl/auxil/pnad-emprego.csv", clear
mat infpnad = J(2,5,-999)
local collbl ""
forvalues colj = 1/5 {
  local varj = `colj' + 1
  mat infpnad[1,`colj'] = real(subinstr(v`varj'[17],",","",.))/real(subinstr(v`varj'[5],",","",.))
  mat infpnad[2,`colj'] = real(subinstr(v`varj'[19],",","",.))/real(subinstr(v`varj'[7],",","",.))
  local addlbl = v`varj'[2]
  local collbl "`collbl' `addlbl'"
  }
matname infpnad `collbl', columns(1..5) explicit
* change colnames from Agricultura Comrcio Manufatura Servios Total to standard
tokenize `collbl'
local newcollbl ""
forvalues j = 1/5 {
  local lbl3 = lower(substr("``j''",1,3))
  local newcollbl "`newcollbl' `lbl3'"
  }
tokenize `newcollbl'
local collbl ""
forvalues j = 1/5 {
 foreach sec in manuf servcs comm agric total {
  if substr("`sec'",1,3)=="``j''"  local collbl "`collbl' `sec'"
  }
 }
matrix colnames infpnad = `collbl'
matorder infpnad, matrix(infpnad) ifc(manuf servcs comm agric total)
matname infpnad infshare_pnad:1990 infshare_pnad:1997, rows(1..2) explicit
drop _all


/* Load RAIS results */

* lnwmeanshr in new sector sequence 4 5 2 1
matload lnwmeanshr_tbl, path(brazempl/tex/v1/tables) over
* Deflate year 1997 with log US CPI .187
foreach rowi in 7 8 9 10 11 12 14 { 
  forvalues colj = 1/4 {
    mat lnwmeanshr_tbl[`rowi',`colj'] = lnwmeanshr_tbl[`rowi',`colj'] - .187
    }
  }
matorder lnwmeanshr_tbl, matrix(rais) ifc(lnw_Manuf)
matorder rais, matrix(rais) over ifr(90alloc 97alloc 90indfem:0 90indfem:1 90indnocoll:0 90indnocoll:1 90indblue:0 90indblue:1 97indfem:0 97indfem:1 97indnocoll:0 97indnocoll:1 97indblue:0 97indblue:1)
matorder lnwmeanshr_tbl, matrix(raisempl) ifc(sh_Manuf sh_Svcs sh_Comm sh_Agric)
matorder raisempl, matrix(raisempl) over ifr(90indfem:0 97indfem:0 90indnocoll:0 97indnocoll:0 90indblue:0 97indblue:0)
mat rownames raisempl = rais
matorder lnwmeanshr_tbl, matrix(raissec) ifc(sh_Manuf sh_Svcs sh_Comm sh_Agric)
matorder raissec, matrix(raissec) over ifr(90alloc 97alloc)
mat roweq raissec = rais 
matorder lnwmeanshr_tbl, matrix(raislnwage) ifc(lnw_Manuf lnw_Svcs lnw_Comm lnw_Agric)
matorder raislnwage, matrix(raislnwage) over ifr(90alloc 97alloc 90indfem:0 90indfem:1 97indfem:0 97indfem:1 90indnocoll:0 90indnocoll:1 97indnocoll:0 97indnocoll:1 90indblue:0 90indblue:1 97indblue:0 97indblue:1)
mat drop lnwmeanshr_tbl


/* Load PNAD for log wages */

* lnwagepnad`mat' in new sector sequence 4 5 2 1
local rownames : rowfullnames raislnwage
disp "`rownames'"
foreach mat in 1 2 {
  mat lnwagepnad`mat' = J(14,6,-999)
  matname lnwagepnad`mat' `rownames', rows(1..14) explicit
  matname lnwagepnad`mat' rais pnadform pnadinf rais pnadform pnadinf, columns(1..6) explicit
  }
mat coleq lnwagepnad1 = manuf manuf manuf servcs servcs servcs
mat coleq lnwagepnad2 = agric agric agric comm comm comm
local count = -1
foreach column in formal informal {
local count = `count' + 1
insheet using "brazempl/auxil/pnad-`column'.csv", clear
keep if v1~=v9 /* remove empty lines */
keep v1 v2-v5 /* wages, all sectors */
rename v1 var
gen str eq = var if v2=="" & v3=="" & v4=="" & v5==""
forvalues var = 2/5 {
  local lbl = v`var'[1]
  label var v`var' "`lbl'"
  }
replace eq = eq[_n-1] if eq==""
replace eq = trim(eq)
replace var = trim(var)
drop if eq=="" | var==""
qui compress
order eq
drop if v2=="" & v3=="" & v4=="" & v5==""
* deflate
forvalues varj = 2/5 {
  rename v`varj' _v`varj'
  local lbl : variable label _v`varj'
  gen v`varj' = real(_v`varj')
  label var v`varj' "`lbl'"
  drop _v`varj'
  * INPC-12/90: 1001.9506 / INPC-9/90: 628.5792 = 1.5940
  * BCR/USD-12/90: 170.06 / BCR/USD-9/90: 84.223 = 2.0192
  * Correction term 1990 (add to PNAD): log((1/2.0192)*1.5940) < 0
  replace v`varj' = v`varj' + log((1/2.0192)*1.5940) if eq=="1990" | var=="1990"
  * INPC-12/97: 26638626 / INPC-9/97: 26371590 = 1.0101
  * BRL/USD-12/90: 1.1149 / BRL/USD-9/90: 1.0954 = 1.0178
  * Correction term 1997 (add to PNAD): log((1/1.0178)*1.0101) < 0
  replace v`varj' = v`varj' + log((1/1.0178)*1.0101) if eq=="1997" | var=="1997"
  }
forvalues var = 2/5 {
  local newname : variable label v`var'
  local newname = lower(substr("`newname'",1,3))
  rename v`var' `newname'
  }
forvalues rowi = 1/14 {
  mat lnwagepnad1[`rowi',2+`count'] = man[`rowi'] /* Manufacturing */
  mat lnwagepnad1[`rowi',5+`count'] = ser[`rowi'] /* Services */
  mat lnwagepnad2[`rowi',2+`count'] = com[`rowi'] /* Commerce */
  mat lnwagepnad2[`rowi',5+`count'] = agr[`rowi'] /* Agriculture */
  }
}
forvalues mat = 1/2 {
  forvalues sec = 1/2 {
    local raiscol = `mat'*2 -1 + (`sec'-1)
    local colj = (`sec'-1)*3 + 1
    forvalues rowi = 1/14 {
      mat lnwagepnad`mat'[`rowi',`colj'] = raislnwage[`rowi',`raiscol']
      }
    }
  }


/* Load PNAD for employment shares */

* emplpnad initially Naercio sector sequence, further below new sector sequence 4 5 2 1
mat emplpnad = J(6,8,-999)
matname emplpnad malefem:1990 malefem:1997 collhigh:1990 collhigh:1997 whitblue:1990 whitblue:1997, rows(1..6) explicit
matname emplpnad f:agric f:comm f:manuf f:servcs inf:agric inf:comm inf:manuf inf:servcs, columns(1..8) explicit
local mincol = -4
foreach column in formal informal {
local mincol = `mincol' + 4
insheet using "brazempl/auxil/pnad-`column'.csv", clear
keep if v1~=v9 /* remove empty lines */
keep v1 v6-v9 /* employment shares, all sectors */
rename v1 var
forvalues var = 6/9 {
  local lbl = v`var'[1]
  label var v`var' "`lbl'"
  }
drop in 2/5 /* drop sector decomp */
drop if var=="Mulher" | var=="at 11" | var=="Blue-collar"
drop if var=="1990" | var=="1997"
forvalues var = 6/9 {
  local newname : variable label v`var'
  local newname = lower(substr("`newname'",1,3))
  rename v`var' `newname'
  }
forvalues i = 2/7 {
  local row = `i' - 1
  local j 0
  foreach sec in agric comm manuf servcs {
    local varcall = lower(substr("`sec'",1,3))
    local j = `j' + 1
    local col = `j' + `mincol'
    mat emplpnad[`row',`col'] = real(`varcall'[`i'])
    }
  }
}
* rearrange Naercio sector sequence to new draft sequence
matorder emplpnad, matrix(emplpnad) over ifc(f:manuf f:servcs f:comm f:agric inf:manuf inf:servcs inf:comm inf:agric)
mat emplpnad = raisempl , J(6,4,-999) \ emplpnad
matname emplpnad f:manuf f:servcs f:comm f:agric inf:manuf inf:servcs inf:comm inf:agric, columns(1..8) explicit
* rearrange informal and formal
matorder emplpnad, matrix(emplpnad) over ifc(f:manuf inf:manuf f:servcs inf:servcs f:comm inf:comm f:agric inf:agric)
* rearrange years
matorder emplpnad, matrix(emplpnad) over ifr(90indfem:rais malefem:1990 97indfem:rais malefem:1997 90indnocoll:rais collhigh:1990 97indnocoll:rais collhigh:1997 90indblue:rais whitblue:1990 97indblue:rais whitblue:1997)


/* Load PNAD for sector allocation */

* forminform initially Naercio sector sequence, then new sector sequence 4 5 2 1
mat secpnad = J(4,4,-999)
matname secpnad pnad_formal:1990 pnad_formal:1997 pnad_informal:1990 pnad_informal:1997, rows(1..4) explicit
matname secpnad agric comm manuf servcs, columns(1..4) explicit
local strtrow = - 1
foreach column in formal informal {
local strtrow = `strtrow' + 1
insheet using "brazempl/auxil/pnad-`column'.csv", clear
keep if v1~=v9 /* remove empty lines */
keep v1 v6-v9 /* employment shares, all sectors */
rename v1 var
forvalues var = 6/9 {
  local lbl = v`var'[1]
  label var v`var' "`lbl'"
  local newname : variable label v`var'
  local newname = lower(substr("`newname'",1,3))
  rename v`var' `newname'
  }
keep in 1/5 /* keep sector decomp */
forvalues i = 4/5 {
  local row = `i' - 3 + 2*`strtrow'
  local j 0
  foreach sec in agric comm manuf servcs {
    local j = `j' + 1
    local varcall = lower(substr("`sec'",1,3))
    local col = `j'
    mat secpnad[`row',`col'] = real(`varcall'[`i'])
    }
  }
}
* transform to new sector sequence 4 5 2 1
matorder infpnad, matrix(infpnad) ifc(manuf servcs comm agric total)
matorder secpnad, matrix(secpnad) ifc(manuf servcs comm agric) over
matorder raissec, matrix(raissec) ifc(sh_Manuf sh_Svcs sh_Comm sh_Agric) over
mat secpnad = raissec \ secpnad
matname secpnad manuf servcs comm agric, columns(1..4) explicit
mat forminform = infpnad \ (secpnad , J(6,1,1) )
matorder forminform, matrix(forminform) over ifr(infshare_pnad:1990 infshare_pnad:1997 rais:90alloc pnad_formal:1990 pnad_informal:1990 rais:97alloc pnad_formal:1997 pnad_informal:1997)

/* Combine wage levels and informality shares for manufacturing */

* lnwmeanshr_pnad uses new sector sequence 4 5 (2 1 ignored, 5 overwritten)
* matorder emplpnad ifr is 90indfem:rais malefem:1990 97indfem:rais malefem:1997 90indnocoll:rais collhigh:1990 97indnocoll:rais collhigh:1997 90indblue:rais whitblue:1990 97indblue:rais whitblue:1997
mat lnwmeanshr_pnad = lnwagepnad1
mat coleq lnwmeanshr_pnad = lnmeanw lnmeanw lnmeanw share share share
foreach yr in 90 97 {
  mat lnwmeanshr_pnad[rownumb(lnwmeanshr_pnad,"`yr'alloc"),colnumb(lnwmeanshr_pnad,"share:rais")]     =   -999
  mat lnwmeanshr_pnad[rownumb(lnwmeanshr_pnad,"`yr'alloc"),colnumb(lnwmeanshr_pnad,"share:pnadinf")]  =   forminform[rownumb(forminform,"infshare_pnad:19`yr'"),colnumb(forminform,"manuf")] /* informal share manuf. */
  mat lnwmeanshr_pnad[rownumb(lnwmeanshr_pnad,"`yr'alloc"),colnumb(lnwmeanshr_pnad,"share:pnadform")] = 1-forminform[rownumb(forminform,"infshare_pnad:19`yr'"),colnumb(forminform,"manuf")] /* formal share manuf. */
  }
foreach grp in indfem indnocoll indblue {
 foreach yr in 90 97 {
  mat lnwmeanshr_pnad[rownumb(lnwmeanshr_pnad,"`yr'`grp':0"),colnumb(lnwmeanshr_pnad,"share:rais")]     =   emplpnad[rownumb(emplpnad,"`yr'`grp':rais")  ,colnumb(emplpnad,"f:manuf")]
  mat lnwmeanshr_pnad[rownumb(lnwmeanshr_pnad,"`yr'`grp':0"),colnumb(lnwmeanshr_pnad,"share:pnadform")] =   emplpnad[rownumb(emplpnad,"`yr'`grp':rais")+1,colnumb(emplpnad,"f:manuf")]
  mat lnwmeanshr_pnad[rownumb(lnwmeanshr_pnad,"`yr'`grp':0"),colnumb(lnwmeanshr_pnad,"share:pnadinf")]  =   emplpnad[rownumb(emplpnad,"`yr'`grp':rais")+1,colnumb(emplpnad,"inf:manuf")]
  mat lnwmeanshr_pnad[rownumb(lnwmeanshr_pnad,"`yr'`grp':1"),colnumb(lnwmeanshr_pnad,"share:rais")]     = 1-emplpnad[rownumb(emplpnad,"`yr'`grp':rais")  ,colnumb(emplpnad,"f:manuf")]
  mat lnwmeanshr_pnad[rownumb(lnwmeanshr_pnad,"`yr'`grp':1"),colnumb(lnwmeanshr_pnad,"share:pnadform")] = 1-emplpnad[rownumb(emplpnad,"`yr'`grp':rais")+1,colnumb(emplpnad,"f:manuf")]
  mat lnwmeanshr_pnad[rownumb(lnwmeanshr_pnad,"`yr'`grp':1"),colnumb(lnwmeanshr_pnad,"share:pnadinf")]  = 1-emplpnad[rownumb(emplpnad,"`yr'`grp':rais")+1,colnumb(emplpnad,"inf:manuf")]
  }
 }


/* Load PNAD for wage differentials */

* premiapnad for manufacturing (4) sector only
mat premiapnad = J(7,4,-999)
matname premiapnad time:1997_1990_all malefem:1990_all malefem:1997_all collhigh:1990_all collhigh:1997_all whitblue:1990_all whitblue:1997_all, rows(1..7) explicit
matname premiapnad pnad_total pnad_formal pnad_informal rais_uncond, columns(1..4) explicit
local col = 0
foreach column in total formal informal {
local col = `col' + 1
insheet using "brazempl/auxil/pnad-`column'.csv", clear
keep if v1~=v9 /* remove empty lines */
keep v1 v2-v5 /* wages, all sectors */
rename v1 var
gen str eq = var if v2=="" & v3=="" & v4=="" & v5==""
forvalues var = 2/5 {
  local lbl = v`var'[1]
  label var v`var' "`lbl'"
  }
replace eq = eq[_n-1] if eq==""
replace eq = trim(eq)
replace var = trim(var)
drop if eq=="" | var==""
qui compress
order eq
drop if v2=="" & v3=="" & v4=="" & v5==""
forvalues varj = 2/5 {
  rename v`varj' _v`varj'
  local lbl : variable label _v`varj'
  gen v`varj' = real(_v`varj')
  label var v`varj' "`lbl'"
  drop _v`varj'
  * INPC-12/90: 1001.9506 / INPC-9/90: 628.5792 = 1.5940
  * BCR/USD-12/90: 170.06 / BCR/USD-9/90: 84.223 = 2.0192
  * Correction term 1990 (add to PNAD): log((1/2.0192)*1.5940) < 0
  replace v`varj' = v`varj' + log((1/2.0192)*1.5940) if eq=="1990" | var=="1990"
  * INPC-12/97: 26638626 / INPC-9/97: 26371590 = 1.0101
  * BRL/USD-12/90: 1.1149 / BRL/USD-9/90: 1.0954 = 1.0178
  * Correction term 1997 (add to PNAD): log((1/1.0178)*1.0101) < 0
  replace v`varj' = v`varj' + log((1/1.0178)*1.0101) if eq=="1997" | var=="1997"
  }
forvalues var = 2/5 {
  local newname : variable label v`var'
  local newname = lower(substr("`newname'",1,3))
  rename v`var' `newname'
  }
keep var man /* manufacturing only */
* sort order of rows in data: 1990 1997 Homen Mulher Homem Mulher maisde11 ate11 maisde11 ate11 white-collar blue-collar white-collar blue-collar
foreach row in 1 {
  local line2 = `row'*2
  local line1 = `line2' - 1
  mat premiapnad[`row',`col'] = exp(man[`line2'])/exp(man[`line1'])
  }
foreach row in 2 3 4 5 6 7 {
  local line2 = `row'*2
  local line1 = `line2' - 1
  mat premiapnad[`row',`col'] = exp(man[`line1'])/exp(man[`line2'])
  }
}

* Add RAIS (rais rows need to be rearranged to: time:1997_1990_all malefem:1990_all malefem:1997_all collhigh:1990_all collhigh:1997_all whitblue:1990_all whitblue:1997_all)
* rearrange RAIS table in Naercio style
matorder rais, matrix(rais) over ifr(90alloc 97alloc 90indfem:1 90indfem:0 97indfem:1 97indfem:0 90indnocoll:1 90indnocoll:0 97indnocoll:1 97indnocoll:0 90indblue:1 90indblue:0 97indblue:1 97indblue:0)
forvalues row = 1/7 {
  local line2 = `row'*2
  local line1 = `line2' - 1
  mat premiapnad[`row',colnumb(premiapnad,"rais_uncond")] = exp(rais[`line2',1])/exp(rais[`line1',1])
  }
matorder premiapnad, matrix(premiapnad) over ifc(rais_uncond pnad_total pnad_formal pnad_informal)


/* Output Tables */

foreach mat in infpnad lnwmeanshr_pnad lnwagepnad1 lnwagepnad2 emplpnad secpnad forminform premiapnad {
  mat rename `mat' `mat'_tbl
  }
est2tex infpnad, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
est2tex emplpnad, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(2 4 6)
est2tex lnwmeanshr_pnad, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(3)
est2tex lnwagepnad1, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(3)
est2tex lnwagepnad2, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(3)
est2tex secpnad, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
est2tex forminform, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
est2tex premiapnad, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(1)
