local refyr = 90
local refsec = 4

version 8
set matsize 120
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture program drop dropmiss
program define dropmiss
    syntax [varlist]
    local nvar : word count `varlist'
    foreach var of local varlist {
      capture drop if `var'==.
      }
end


/* EDUCATION and OCCUPATION PROFILES */
/*-----------------------------------*/

foreach profile in edu occu {

if "`profile'"=="edu" {
  local proflvar1 "prim"
  local proflvar2 "high"
  local proflvar3 "coll"
  local proflvar4 "grad"
  }
if "`profile'"=="occu" {
  local proflvar1 "prof"
  local proflvar2 "tech"
  local proflvar3 "whit"
  local proflvar4 "sklb"
  }

/* AKMT estimates and summary statistics */

local yr = `refyr'
local sec = `refsec'
insheet using "brazempl/auxil/akmt-worker-plantfe.csv", comma names clear
replace _rowname=lower(_rowname)
replace _rowname=subinstr(_rowname," ","",.)
keep _rowname fr92coeff us90bcoeff
dropmiss
preserve
    drop if substr(_rowname,-4,4)=="`proflvar1'" | substr(_rowname,-4,4)=="`proflvar2'" | substr(_rowname,-4,4)=="`proflvar3'" | substr(_rowname,-4,4)=="`proflvar4'"
    save "brazempl/auxil/akmtb`profile'out", replace
    drop _all
    matload akmtb`profile'out, path(brazempl/auxil) over
restore, preserve
    keep if substr(_rowname,-4,4)=="`proflvar1'" | substr(_rowname,-4,4)=="`proflvar2'" | substr(_rowname,-4,4)=="`proflvar3'" | substr(_rowname,-4,4)=="`proflvar4'"
    save "brazempl/auxil/akmtb`profile'in", replace
    drop _all
    matload akmtb`profile'in, path(brazempl/auxil) over
restore
insheet using "brazempl/auxil/akmt-summdata.csv", comma names clear
keep _rowname fr92mean us90mean
replace _rowname=lower(_rowname)
replace _rowname=subinstr(_rowname," ","",.)
drop if _rowname=="ln_wage" | _rowname=="indmetro" | _rowname=="fem_indmetro" | _rowname=="indposgr" | _rowname=="fem_indposgr" | _rowname=="fem_indmetro" | _rowname=="indnoskl" | _rowname=="fem_indnoskl"
dropmiss
    drop if substr(_rowname,-4,4)=="`proflvar1'" | substr(_rowname,-4,4)=="`proflvar2'" | substr(_rowname,-4,4)=="`proflvar3'" | substr(_rowname,-4,4)=="`proflvar4'"
    save "brazempl/auxil/akmtmean`profile'out", replace
    drop _all
    matload akmtmean`profile'out, path(brazempl/auxil) over
mat _xbfrmasc = akmtb`profile'out[1..8,1] '  * akmtmean`profile'out[1..8,1]
mat _xbfrfemi = akmtb`profile'out[1..17,1] ' * akmtmean`profile'out[1..17,1]
mat _xbusmasc = akmtb`profile'out[1..8,2] '  * akmtmean`profile'out[1..8,2]
mat _xbusfemi = akmtb`profile'out[1..17,2] ' * akmtmean`profile'out[1..17,2]
mat drop akmtb`profile'out akmtmean`profile'out
mat _xbmasc = _xbfrmasc , _xbusmasc
mat _xbfemi = _xbfrfemi , _xbusfemi
mat drop _xbfrmasc _xbfrfemi _xbusmasc _xbusfemi
matname _xbmasc xbhatmasc, rows(1) explicit
matname _xbfemi xbhatfemi, rows(1) explicit
mat comp = akmtb`profile'in \ _xbmasc
mat comp = comp \ _xbfemi
mat drop _xbmasc _xbfemi
mat comp = comp \ J(1,2,-999)
insheet using "brazempl/auxil/fr92edu.csv", comma names clear
keep _rowname mean
keep if _rowname == "psihat"
mat comp[11,1] = mean[1]
insheet using "brazempl/auxil/us90edu.csv", comma names clear
keep _rowname mean
keep if _rowname == "psihat"
mat comp[11,2] = mean[1]
matname comp psihat, rows(11) explicit


/* Brazil 1990 and 1997, all sectors */

* matload cntfemtot, path(rais-sp/rais) over dropall
* matload cntmasctot, path(rais-sp/rais) over dropall

/* use regression results w/ education indicators */
foreach yr in 90 97 {
foreach sec in 4 {
* Education variables
use "brazempl/tex/heckman/wage/wageheckman`yr'sec`sec'_tbl", clear
drop if substr(_rowname[_n-1],1,9)=="indselct:"
drop if substr(_rowname,1,9)=="indselct:"
replace _rowname = subinstr(_rowname,"lnwage:","",.)
keep _rowname yr`yr'sec`sec'eduxtreg  /* regression results w/ education indicators */
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
drop if _rowname=="_se"
keep if substr(_rowname,-4,4)=="`proflvar1'" | substr(_rowname,-4,4)=="`proflvar2'" | substr(_rowname,-4,4)=="`proflvar3'" | substr(_rowname,-4,4)=="`proflvar4'"
save "brazempl/est/heckman/br`yr'sec`sec'_`profile'in", replace
drop _all
matload br`yr'sec`sec'_`profile'in, path(brazempl/est/heckman) over
erase brazempl\est\heckman\br`yr'sec`sec'_`profile'in.dta
use "brazempl/tex/heckman/corr/corrxtreg`yr'sec`sec'edu_tbl", clear
keep _rowname mean
keep if _rowname=="xbhat" | _rowname=="psihat" | substr(_rowname,1,5)=="mills"
save "brazempl/est/heckman/br`yr'sec`sec'_mean`profile'out", replace
drop _all
matload br`yr'sec`sec'_mean`profile'out, path(brazempl/est/heckman) over
erase brazempl\est\heckman\br`yr'sec`sec'_mean`profile'out.dta
* Other variables than `profile'
tempfile summtex
use "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl", clear
keep _rowname mean
drop if substr(_rowname,-6,6)=="unsklb"
compress
sort _rowname
save `summtex'
use "brazempl/tex/heckman/wage/wageheckman`yr'sec`sec'_tbl", clear
drop if substr(_rowname[_n-1],1,9)=="indselct:"
drop if substr(_rowname,1,9)=="indselct:"
replace _rowname = subinstr(_rowname,"lnwage:","",.)
keep _rowname yr`yr'sec`sec'eduxtreg
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
drop if _rowname=="_se"
drop if substr(_rowname,-4,4)=="`proflvar1'" | substr(_rowname,-4,4)=="`proflvar2'" | substr(_rowname,-4,4)=="`proflvar3'" | substr(_rowname,-4,4)=="`proflvar4'"
/* following line depends on use of education regression results */
keep if substr(_rowname,-5,5) == "exper" | substr(_rowname,-5,5) == "xper2" | substr(_rowname,-5,5) == "xper3" | substr(_rowname,-5,5) == "xper4" | substr(_rowname,-4,4) == "prof" | substr(_rowname,-4,4) == "tech" | substr(_rowname,-4,4)=="whit" | substr(_rowname,-4,4)=="sklb" | substr(_rowname,-4,4)=="prim" | substr(_rowname,-4,4)=="high" | substr(_rowname,-4,4)=="coll" | substr(_rowname,-4,4)=="grad" | substr(_rowname,-4,4)=="dfem" | substr(_rowname,-4,4)=="cons"
gen _count = _n
sort _rowname
merge _rowname using "`summtex'", nokeep
drop _m
sort _count
drop _count
save "brazempl/est/heckman/mmr`yr'sec`sec'`profile'", replace
drop _all
matload mmr`yr'sec`sec'`profile', path(brazempl/est/heckman) over
erase brazempl\est\heckman\mmr`yr'sec`sec'`profile'.dta
local rownum = rowsof(mmr`yr'sec`sec'`profile')
forvalues i = 1/`rownum' {
 forvalues j = 1/2 {
  if mmr`yr'sec`sec'`profile'[`i',`j'] == -999 {
    mat mmr`yr'sec`sec'`profile'[`i',`j'] = 0
    }
   }
  }
* Multiply point estimate by sample mean (multiplication by mean zero when point estimate missing)
mat _xbbrmasc`yr'sec`sec' = mmr`yr'sec`sec'`profile'[1..8,1] '  * mmr`yr'sec`sec'`profile'[1..8,2]
mat _xbbrfemi`yr'sec`sec' = mmr`yr'sec`sec'`profile'[1..17,1] ' * mmr`yr'sec`sec'`profile'[1..17,2]
mat drop mmr`yr'sec`sec'`profile'
}
}

local rownames : rownames comp
foreach sec in 4 {
mat _brcomp`sec' = br90sec`sec'_`profile'in , br97sec`sec'_`profile'in
mat drop br90sec`sec'_`profile'in br97sec`sec'_`profile'in
mat _xbbrmasc`sec' = _xbbrmasc90sec`sec' , _xbbrmasc97sec`sec'
mat _xbbrfemi`sec' = _xbbrfemi90sec`sec' , _xbbrfemi97sec`sec'
mat drop _xbbrmasc90sec`sec' _xbbrmasc97sec`sec' _xbbrfemi90sec`sec' _xbbrfemi97sec`sec'
mat _brpsihat`sec' = br90sec`sec'_mean`profile'out[2,1] , br97sec`sec'_mean`profile'out[2,1]
mat _brmills`sec' = br90sec`sec'_mean`profile'out[3,1] , br97sec`sec'_mean`profile'out[3,1]
mat drop br90sec`sec'_mean`profile'out br97sec`sec'_mean`profile'out
mat _brcomp`sec' = _brcomp`sec' \ _xbbrmasc`sec'
mat _brcomp`sec' = _brcomp`sec' \ _xbbrfemi`sec'
mat _brcomp`sec' = _brcomp`sec' \ _brpsihat`sec'
mat _brcomp`sec' = _brcomp`sec' \ _brmills`sec'
mat drop _xbbrmasc`sec' _xbbrfemi`sec' _brpsihat`sec' _brmills`sec'
matname _brcomp`sec' `rownames' mills, rows(1..12) explicit
}

local sec 4
mat comp`profile'_tbl = _brcomp`sec' , ( comp \ J(1,2,-999) )
mat drop comp akmtb`profile'in
mat braz`profile'in_tbl = _brcomp4

} /* end profile loop */


/* EDUCATION tabulations: Brazil, France, US */

local yr = `refyr'
local sec = `refsec'
mat _seeddta = (1)
drop _all
svmat _seeddta
mat drop _seeddta
rename _seeddta1 _rowname
local rows = rowsof(compedu_tbl)
local cols = colsof(compedu_tbl)
forvalues i = 1/`rows' {
  forvalues j = 1/`cols' {
    if compedu_tbl[`i',`j']==-999 {
      mat compedu_tbl[`i',`j']=0
      }
    }
  }
local j = 0
foreach var in br90sec4 br97sec4 fr92 us90b {
  local j = `j' + 1
  local k = 0
  foreach edulvl in prim high scoll {
    local k = `k' + 1    
    local kfem = `k' + 4
    gen `var'_`edulvl'_0 = exp( compedu_tbl[`k',`j'] * _rowname + compedu_tbl[4,`j'] * _rowname + compedu_tbl[9,`j'] + compedu_tbl[11,`j'] ) 
    gen `var'_`edulvl'_1 = exp( ln(`var'_`edulvl'_0) + compedu_tbl[`kfem',`j'] * _rowname + compedu_tbl[8,`j'] * _rowname + compedu_tbl[10,`j'] )
    replace `var'_`edulvl'_0 = `var'_`edulvl'_0 / exp( compedu_tbl[9,`j'] + compedu_tbl[11,`j'] )
    replace `var'_`edulvl'_1 = `var'_`edulvl'_1 / exp( compedu_tbl[9,`j'] + compedu_tbl[10,`j'] + compedu_tbl[11,`j'] )
    }
  }
foreach edulvl in prim high scoll {
  foreach gender in 0 1 {
    label var br90sec4_`edulvl'_`gender' "Brazil 1990"
    label var br97sec4_`edulvl'_`gender' "Brazil 1997"
    label var fr92_`edulvl'_`gender' "France 1992"
    label var us90b_`edulvl'_`gender' "USA 1990"
    }
  }
reshape long br90sec4_ br97sec4_ fr92_ us90b_, i(_rowname) j(edu_gender) string
replace edu_gender = subinstr(edu_gender,"_0",":masc",.)
replace edu_gender = subinstr(edu_gender,"_1",":fem",.)
drop _rowname
rename edu_gender _rowname
foreach var in br90sec4 br97sec4 fr92 us90b {
  rename `var'_ `var'
  }
label var br90sec4 "Brazil 1990"
label var br97sec4 "Brazil 1997"
label var fr92 "France 1992"
label var us90b "USA 1990"
gen byte gender = ( substr(_rowname,-4,4) == ":fem" )
gen byte hier = 1 if substr(_rowname,1,4) == "grad"
replace  hier = 2 if substr(_rowname,1,4) == "scol"
replace  hier = 3 if substr(_rowname,1,4) == "high"
replace  hier = 4 if substr(_rowname,1,4) == "prim"
sort gender hier
drop hier gender
save "brazempl/tex/heckman/tables/prflcompedu_tbl", replace
matload prflcompedu_tbl, p(brazempl/tex/heckman/tables) over dropall
est2tex prflcompedu, replace dropall preserve ready path(brazempl/tex/heckman/tables) fancy


/* EDUCATION tabulations: Sectors within Brazil */

mat _seeddta = (1)
drop _all
svmat _seeddta
mat drop _seeddta
rename _seeddta1 _rowname
local j = 0
foreach var in br90sec1 br97sec1 br90sec2 br97sec2 br90sec4 br97sec4 br90sec5 br97sec5 {
  local j = `j' + 1
  local k = 0
  foreach edulvl in prim high scoll grad {
    local k = `k' + 1    
    local kfem = `k' + 4
    gen `var'_`edulvl'_0 = exp( brazeduin_tbl[`k',`j'] * _rowname + brazeduin_tbl[9,`j'] + brazeduin_tbl[11,`j'] ) 
    gen `var'_`edulvl'_1 = exp( ln(`var'_`edulvl'_0) + brazeduin_tbl[`kfem',`j'] * _rowname + brazeduin_tbl[10,`j'] )
    replace `var'_`edulvl'_0 = `var'_`edulvl'_0 / exp( brazeduin_tbl[9,`j'] + brazeduin_tbl[11,`j'] )
    replace `var'_`edulvl'_1 = `var'_`edulvl'_1 / exp( brazeduin_tbl[9,`j'] + brazeduin_tbl[10,`j'] + brazeduin_tbl[11,`j'] )
    }
  }
foreach edulvl in prim high scoll grad {
 foreach gender in 0 1 {
  foreach yr in 90 97 {
    label var br`yr'sec1_`edulvl'_`gender' "Agriculture 19`yr'"
    label var br`yr'sec2_`edulvl'_`gender' "Commerce 19`yr'"
    label var br`yr'sec4_`edulvl'_`gender' "Manufacturing 19`yr'"
    label var br`yr'sec5_`edulvl'_`gender' "Services 19`yr'"
    }
   }
  }
reshape long br90sec1_ br97sec1_ br90sec2_ br97sec2_ br90sec4_ br97sec4_ br90sec5_ br97sec5_, i(_rowname) j(edu_gender) string
replace edu_gender = subinstr(edu_gender,"_0",":masc",.)
replace edu_gender = subinstr(edu_gender,"_1",":fem",.)
drop _rowname
rename edu_gender _rowname
foreach var in br90sec1 br97sec1 br90sec2 br97sec2 br90sec4 br97sec4 br90sec5 br97sec5 {
  rename `var'_ `var'
  }
foreach yr in 90 97 {
  label var br`yr'sec1 "Agriculture 19`yr'"
  label var br`yr'sec2 "Commerce 19`yr'"
  label var br`yr'sec4 "Manufacturing 19`yr'"
  label var br`yr'sec5 "Services 19`yr'"
  }
gen byte gender = ( substr(_rowname,-4,4) == ":fem" )
gen byte hier = 1 if substr(_rowname,1,4) == "grad"
replace  hier = 2 if substr(_rowname,1,4) == "scol"
replace  hier = 3 if substr(_rowname,1,4) == "high"
replace  hier = 4 if substr(_rowname,1,4) == "prim"
sort gender hier
drop hier gender
drop if substr(_rowname,1,4) == "grad"
save "brazempl/tex/heckman/tables/prflbrsecedu_tbl", replace
matload prflbrsecedu_tbl, p(brazempl/tex/heckman/tables) over dropall
est2tex prflbrsecedu, replace dropall preserve ready path(brazempl/tex/heckman/tables) fancy


/* OCCUPATION tabulations: Brazil, France, US */

local yr = `refyr'
local sec = `refsec'
mat _seeddta = (1)
drop _all
svmat _seeddta
mat drop _seeddta
rename _seeddta1 _rowname
local j = 0
foreach var in br90sec4 br97sec4 fr92 us90b {
  local j = `j' + 1
  local k = 0
  foreach occulvl in prof tech whit sklb {
    local k = `k' + 1    
    local kfem = `k' + 4
    gen `var'_`occulvl'_0 = exp( compoccu_tbl[`k',`j'] * _rowname + compoccu_tbl[9,`j'] + compoccu_tbl[11,`j'] ) 
    gen `var'_`occulvl'_1 = exp( ln(`var'_`occulvl'_0) + compoccu_tbl[`kfem',`j'] * _rowname + compoccu_tbl[10,`j'] )
    replace `var'_`occulvl'_0 = `var'_`occulvl'_0 / exp( compoccu_tbl[9,`j'] + compoccu_tbl[11,`j'] )
    replace `var'_`occulvl'_1 = `var'_`occulvl'_1 / exp( compoccu_tbl[9,`j'] + compoccu_tbl[10,`j'] + compoccu_tbl[11,`j'] )
    }
  }
foreach occulvl in prof tech whit sklb {
  foreach gender in 0 1 {
    label var br90sec4_`occulvl'_`gender' "Brazil 1990"
    label var br97sec4_`occulvl'_`gender' "Brazil 1997"
    label var fr92_`occulvl'_`gender' "France 1992"
    label var us90b_`occulvl'_`gender' "USA 1990"
    }
  }
reshape long br90sec4_ br97sec4_ fr92_ us90b_, i(_rowname) j(occu_gender) string
replace occu_gender = subinstr(occu_gender,"_0",":masc",.)
replace occu_gender = subinstr(occu_gender,"_1",":fem",.)
drop _rowname
rename occu_gender _rowname
foreach var in br90sec4 br97sec4 fr92 us90b {
  rename `var'_ `var'
  }
label var br90sec4 "Brazil 1990"
label var br97sec4 "Brazil 1997"
label var fr92 "France 1992"
label var us90b "USA 1990"
gen byte gender = ( substr(_rowname,-4,4) == ":fem" )
gen byte hier = 1 if substr(_rowname,1,4) == "prof"
replace  hier = 2 if substr(_rowname,1,4) == "tech"
replace  hier = 3 if substr(_rowname,1,4) == "whit"
replace  hier = 4 if substr(_rowname,1,4) == "sklb"
sort gender hier
drop hier gender
save "brazempl/tex/heckman/tables/prflcompoccu_tbl", replace
matload prflcompoccu_tbl, p(brazempl/tex/heckman/tables) over dropall
est2tex prflcompoccu, replace dropall preserve ready path(brazempl/tex/heckman/tables) fancy


/* OCCUPATION tabulations: Sectors within Brazil */

mat _seeddta = (1)
drop _all
svmat _seeddta
mat drop _seeddta
rename _seeddta1 _rowname
local j = 0
foreach var in br90sec1 br97sec1 br90sec2 br97sec2 br90sec4 br97sec4 br90sec5 br97sec5 {
  local j = `j' + 1
  local k = 0
  foreach occulvl in prof tech whit sklb {
    local k = `k' + 1    
    local kfem = `k' + 4
    gen `var'_`occulvl'_0 = exp( brazoccuin_tbl[`k',`j'] * _rowname + brazoccuin_tbl[9,`j'] + brazoccuin_tbl[11,`j'] ) 
    gen `var'_`occulvl'_1 = exp( ln(`var'_`occulvl'_0) + brazoccuin_tbl[`kfem',`j'] * _rowname + brazoccuin_tbl[10,`j'] )
    replace `var'_`occulvl'_0 = `var'_`occulvl'_0 / exp( brazoccuin_tbl[9,`j'] + brazoccuin_tbl[11,`j'] )
    replace `var'_`occulvl'_1 = `var'_`occulvl'_1 / exp( brazoccuin_tbl[9,`j'] + brazoccuin_tbl[10,`j'] + brazoccuin_tbl[11,`j'] )
    }
  }
foreach occulvl in prof tech whit sklb {
 foreach gender in 0 1 {
  foreach yr in 90 97 {
    label var br`yr'sec2_`occulvl'_`gender' "Commerce 19`yr'"
    label var br`yr'sec4_`occulvl'_`gender' "Manufacturing 19`yr'"
    label var br`yr'sec5_`occulvl'_`gender' "Services 19`yr'"
    }
   }
  }
reshape long br90sec1_ br97sec1_ br90sec2_ br97sec2_ br90sec4_ br97sec4_ br90sec5_ br97sec5_, i(_rowname) j(occu_gender) string
replace occu_gender = subinstr(occu_gender,"_0",":masc",.)
replace occu_gender = subinstr(occu_gender,"_1",":fem",.)
drop _rowname
rename occu_gender _rowname
foreach var in br90sec1 br97sec1 br90sec2 br97sec2 br90sec4 br97sec4 br90sec5 br97sec5 {
  rename `var'_ `var'
  }
foreach yr in 90 97 {
  label var br`yr'sec2 "Commerce 19`yr'"
  label var br`yr'sec4 "Manufacturing 19`yr'"
  label var br`yr'sec5 "Services 19`yr'"
  }
gen byte gender = ( substr(_rowname,-4,4) == ":fem" )
gen byte hier = 1 if substr(_rowname,1,4) == "prof"
replace  hier = 2 if substr(_rowname,1,4) == "tech"
replace  hier = 3 if substr(_rowname,1,4) == "whit"
replace  hier = 4 if substr(_rowname,1,4) == "sklb"
sort gender hier
drop hier gender
save "brazempl/tex/heckman/tables/prflbrsecoccu_tbl", replace
matload prflbrsecoccu_tbl, p(brazempl/tex/heckman/tables) over dropall
est2tex prflbrsecoccu, replace dropall preserve ready path(brazempl/tex/heckman/tables) fancy


/* GENDER PROFILES */
/*----------------*/

local profile "sex"

/* AKMT estimates and summary statistics */

local yr = `refyr'
local sec = `refsec'
insheet using "brazempl/auxil/akmt-worker-plantfe.csv", comma names clear
replace _rowname=lower(_rowname)
replace _rowname=subinstr(_rowname," ","",.)
keep _rowname fr92coeff us90bcoeff
dropmiss
preserve
    drop if substr(_rowname,1,4)=="fem_" | _rowname=="indfem"
    save "brazempl/auxil/akmtb`profile'masc", replace
    drop _all
    matload akmtb`profile'masc, path(brazempl/auxil) over
restore, preserve
    keep if substr(_rowname,1,4)=="fem_" | _rowname=="indfem"
    save "brazempl/auxil/akmtb`profile'femi", replace
    drop _all
    matload akmtb`profile'femi, path(brazempl/auxil) over
restore
insheet using "brazempl/auxil/akmt-summdata.csv", comma names clear
keep _rowname fr92mean us90mean
replace _rowname=lower(_rowname)
replace _rowname=subinstr(_rowname," ","",.)
drop if _rowname=="ln_wage" | _rowname=="indmetro" | _rowname=="fem_indmetro" | _rowname=="indposgr" | _rowname=="fem_indposgr" | _rowname=="fem_indmetro" | _rowname=="indnoskl" | _rowname=="fem_indnoskl"
dropmiss
preserve
    drop if substr(_rowname,1,4)=="fem_" | _rowname=="indfem"
    save "brazempl/auxil/akmtmean`profile'masc", replace
    drop _all
    matload akmtmean`profile'masc, path(brazempl/auxil) over
restore, preserve
    keep if substr(_rowname,1,4)=="fem_" | _rowname=="indfem"
    save "brazempl/auxil/akmtmean`profile'femi", replace
    drop _all
    matload akmtmean`profile'femi, path(brazempl/auxil) over
restore
mat _xbfrmasc = akmtb`profile'masc[1..12,1] '  * akmtmean`profile'masc[1..12,1]
mat _xbfrfemi = akmtb`profile'femi[1..13,1] ' * akmtmean`profile'femi[1..13,1]
mat _xbusmasc = akmtb`profile'masc[1..12,2] '  * akmtmean`profile'masc[1..12,2]
mat _xbusfemi = akmtb`profile'femi[1..13,2] ' * akmtmean`profile'femi[1..13,2]
mat drop akmtb`profile'masc akmtb`profile'femi akmtmean`profile'masc
mat _xbmasc = _xbfrmasc , _xbusmasc
mat _xbfemi = _xbfrfemi , _xbusfemi
mat drop _xbfrmasc _xbfrfemi _xbusmasc _xbusfemi
matname _xbmasc xbhatmasc, rows(1) explicit
matname _xbfemi xbhatfemi, rows(1) explicit
mat comp = _xbmasc \ _xbfemi
mat drop _xbmasc _xbfemi
mat comp = comp \ J(1,2,-999)
insheet using "brazempl/auxil/fr92edu.csv", comma names clear
keep _rowname mean
keep if _rowname == "psihat"
mat comp[3,1] = mean[1]
insheet using "brazempl/auxil/us90edu.csv", comma names clear
keep _rowname mean
keep if _rowname == "psihat"
mat comp[3,2] = mean[1]
matname comp psihat, rows(3) explicit


/* Brazil 1990 and 1997, all sectors */

* matload cntfemtot, path(rais-sp/rais) over dropall
* matload cntmasctot, path(rais-sp/rais) over dropall

/* use regression results w/ education indicators */
foreach yr in 90 97 {
foreach sec in 4 {
* Education variables
use "brazempl/tex/heckman/wage/wageheckman`yr'sec`sec'_tbl", clear
drop if substr(_rowname[_n-1],1,9)=="indselct:"
drop if substr(_rowname,1,9)=="indselct:"
replace _rowname = subinstr(_rowname,"lnwage:","",.)
keep _rowname yr`yr'sec`sec'eduxtreg  /* regression results w/ education indicators */
drop if _rowname=="_se"
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
keep if substr(_rowname,1,4)=="fem_" | _rowname=="indfem"
save "brazempl/est/heckman/br`yr'sec`sec'_`profile'femi", replace
drop _all
matload br`yr'sec`sec'_`profile'femi, path(brazempl/est/heckman) over
erase brazempl\est\heckman\br`yr'sec`sec'_`profile'femi.dta
use "brazempl/tex/heckman/corr/corrxtreg`yr'sec`sec'edu_tbl", clear
keep _rowname mean
keep if _rowname=="xbhat" | _rowname=="psihat"
save "brazempl/est/heckman/br`yr'sec`sec'_mean`profile'masc", replace
drop _all
matload br`yr'sec`sec'_mean`profile'masc, path(brazempl/est/heckman) over
erase brazempl\est\heckman\br`yr'sec`sec'_mean`profile'masc.dta
* Other variables than `profile'
tempfile summtex
use "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl", clear
keep _rowname mean
compress
sort _rowname
save `summtex'
use "brazempl/tex/heckman/wage/wageheckman`yr'sec`sec'_tbl", clear
drop if substr(_rowname[_n-1],1,9)=="indselct:"
drop if substr(_rowname,1,9)=="indselct:"
replace _rowname = subinstr(_rowname,"lnwage:","",.)
keep _rowname yr`yr'sec`sec'eduxtreg
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
drop if _rowname=="_se"
/* following line depends on use of education regression results */
keep if substr(_rowname,-5,5) == "exper" | substr(_rowname,-5,5) == "xper2" | substr(_rowname,-5,5) == "xper3" | substr(_rowname,-5,5) == "xper4" | substr(_rowname,-4,4) == "prof" | substr(_rowname,-4,4) == "tech" | substr(_rowname,-4,4)=="whit" | substr(_rowname,-4,4)=="sklb" | substr(_rowname,-4,4)=="prim" | substr(_rowname,-4,4)=="high" | substr(_rowname,-4,4)=="coll" | substr(_rowname,-4,4)=="grad" | substr(_rowname,-4,4)=="dfem" | substr(_rowname,-4,4)=="cons"
gen _count = _n
sort _rowname
merge _rowname using "`summtex'", nokeep
drop _m
sort _count
drop _count
save "brazempl/est/heckman/mmr`yr'sec`sec'`profile'", replace
drop _all
matload mmr`yr'sec`sec'`profile', path(brazempl/est/heckman) over
erase brazempl\est\heckman\mmr`yr'sec`sec'`profile'.dta
local rownum = rowsof(mmr`yr'sec`sec'`profile')
forvalues i = 1/`rownum' {
 forvalues j = 1/2 {
  if mmr`yr'sec`sec'`profile'[`i',`j'] == -999 {
    mat mmr`yr'sec`sec'`profile'[`i',`j'] = 0
    }
   }
  }
* Multiply point estimate by sample mean (multiplication by mean zero when point estimate missing)
mat _xbbrmasc`yr'sec`sec' = mmr`yr'sec`sec'`profile'[1..12,1] '  * mmr`yr'sec`sec'`profile'[1..12,2]
mat _xbbrfemi`yr'sec`sec' = mmr`yr'sec`sec'`profile'[13..25,1] ' * mmr`yr'sec`sec'`profile'[13..25,2]
mat drop mmr`yr'sec`sec'`profile'
}
}
local rownames : rownames comp
foreach sec in 4 {
mat _brcomp`sec' = br90sec`sec'_`profile'femi , br97sec`sec'_`profile'femi
local colnames : colfullnames _brcomp`sec'
mat drop _brcomp`sec'
mat drop br90sec`sec'_`profile'femi br97sec`sec'_`profile'femi
mat _xbbrmasc`sec' = _xbbrmasc90sec`sec' , _xbbrmasc97sec`sec'
mat _xbbrfemi`sec' = _xbbrfemi90sec`sec' , _xbbrfemi97sec`sec'
mat drop _xbbrmasc90sec`sec' _xbbrmasc97sec`sec' _xbbrfemi90sec`sec' _xbbrfemi97sec`sec'
mat _brpsihat`sec' = br90sec`sec'_mean`profile'masc[2,1] , br97sec`sec'_mean`profile'masc[2,1]
mat drop br90sec`sec'_mean`profile'masc br97sec`sec'_mean`profile'masc
mat _brcomp`sec' = _xbbrmasc`sec' \ _xbbrfemi`sec' \ _brpsihat`sec'
mat drop _xbbrmasc`sec' _xbbrfemi`sec' _brpsihat`sec'
matname _brcomp`sec' `rownames', rows(1..3) explicit
matname _brcomp`sec' `colnames', columns(1..2) explicit
}

local sec 4
mat comp`profile'_tbl = _brcomp`sec' , comp
mat drop comp
mat braz`profile'femi_tbl = _brcomp4


/* GENDER tabulations: Brazil, France, US */

local yr = `refyr'
local sec = `refsec'
mat _seeddta = (1)
drop _all
svmat _seeddta
mat drop _seeddta
rename _seeddta1 _rowname
local rows = rowsof(compsex_tbl)
local cols = colsof(compsex_tbl)
forvalues i = 1/`rows' {
  forvalues j = 1/`cols' {
    if compsex_tbl[`i',`j']==-999 {
      mat compsex_tbl[`i',`j']=0
      }
    }
  }
local j = 0
foreach var in br90sec4 br97sec4 fr92 us90b {
  local j = `j' + 1
  gen `var'_masc = exp( compsex_tbl[1,`j'] * _rowname + compsex_tbl[3,`j'] ) 
  gen `var'_femi = exp( ln(`var'_masc) + compsex_tbl[2,`j'] * _rowname )
  replace `var'_femi = `var'_femi / `var'_masc
  replace `var'_masc = 1
  }
foreach gender in masc femi {
  label var br90sec4_`gender' "Brazil 1990"
  label var br97sec4_`gender' "Brazil 1997"
  label var fr92_`gender' "France 1992"
  label var us90b_`gender' "USA 1990"
  }
reshape long br90sec4_ br97sec4_ fr92_ us90b_, i(_rowname) j(gender) string
drop _rowname
rename gender _rowname
foreach var in br90sec4 br97sec4 fr92 us90b {
  rename `var'_ `var'
  }
label var br90sec4 "Brazil 1990"
label var br97sec4 "Brazil 1997"
label var fr92 "France 1992"
label var us90b "USA 1990"
sort _rowname
compress
save "brazempl/tex/heckman/tables/prflcompsex_tbl", replace
matload prflcompsex_tbl, p(brazempl/tex/heckman/tables) over dropall
est2tex prflcompsex, replace dropall preserve ready path(brazempl/tex/heckman/tables) fancy


/* GENDER tabulations: Sectors within Brazil */

mat _seeddta = (1)
drop _all
svmat _seeddta
mat drop _seeddta
rename _seeddta1 _rowname
local j = 0
foreach var in br90sec1 br97sec1 br90sec2 br97sec2 br90sec4 br97sec4 br90sec5 br97sec5 {
  local j = `j' + 1
  gen `var'_masc = exp( brazsexfemi_tbl[1,`j'] * _rowname + brazsexfemi_tbl[3,`j'] ) 
  gen `var'_femi = exp( ln(`var'_masc) + brazsexfemi_tbl[2,`j'] * _rowname )
  replace `var'_femi = `var'_femi / `var'_masc
  replace `var'_masc = 1
  }
foreach gender in masc femi {
  foreach yr in 90 97 {
    label var br`yr'sec1_`gender' "Agriculture 19`yr'"
    label var br`yr'sec2_`gender' "Commerce 19`yr'"
    label var br`yr'sec4_`gender' "Manufacturing 19`yr'"
    label var br`yr'sec5_`gender' "Services 19`yr'"
    }
  }
reshape long br90sec1_ br97sec1_ br90sec2_ br97sec2_ br90sec4_ br97sec4_ br90sec5_ br97sec5_, i(_rowname) j(gender) string
drop _rowname
rename gender _rowname
foreach var in br90sec1 br97sec1 br90sec2 br97sec2 br90sec4 br97sec4 br90sec5 br97sec5 {
  rename `var'_ `var'
  }
foreach yr in 90 97 {
  label var br`yr'sec1 "Agriculture 19`yr'"
  label var br`yr'sec2 "Commerce 19`yr'"
  label var br`yr'sec4 "Manufacturing 19`yr'"
  label var br`yr'sec5 "Services 19`yr'"
  }
sort _rowname
compress
save "brazempl/tex/heckman/tables/prflbrsecsex_tbl", replace
matload prflbrsecsex_tbl, p(brazempl/tex/heckman/tables) over dropall
est2tex prflbrsecsex, replace dropall preserve ready path(brazempl/tex/heckman/tables) fancy

set more off
cd "$home"
