version 6 
clear
set matsize 300
set logtype text
set mem 900m
capture set mem 950m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture log close
log using "brazempl/logs/heckman-rais.log", replace

local infrm heckman
local sec 4

capture program drop varprep
program define varprep
    args sec yr
    replace lnwage = . if indinfrm==1
    gen byte indselct = 1 - indinfrm
    label var indselct "Formality Selection"
    local secname : label sector `sec'
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sector: " in yellow "`sec'" in green " (" in yellow "`secname'" in green ")"
    disp
    * tab sector
    * tab sector, nolab
    keep if sector==`sec'
    sort worker
    capture confirm numeric variable indprof indtech indwhit indsklb 
    if _rc == 0 {
      local occulst "indprof indtech indwhit indsklb"
      }
    foreach var in potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indprim indhigh indprim_alt indhigh_alt indscoll indgrad indblue `occulst' {
      local dattyp = ""
      if substr("`var'",1,3)=="ind" {
          local dattyp = "byte"
          }
      gen `dattyp' fem_`var' = indfem * `var'
      local lbl : variable label `var'
      local lbl = subinstr("`lbl'"," (at plant)","",.)
      local lbl = subinstr("`lbl'"," Term","",.)
      local lbl = subinstr("`lbl'"," Occupation","",.)
      local lbl = subinstr("`lbl'"," Education","",.)
      local lbl = "Fem. " + "`lbl'" + " Interact."
      local lbl = substr("`lbl'",1,32)
      label var fem_`var' "`lbl'"
      }
    compress
    drop sector
end

capture program drop corrtab
program define corrtab
    args regname yr sec infrm one mills
    predict double xbhat if e(sample)
    replace xbhat = xbhat - _coef[`one']
    gen double psihat = _coef[`one']
    gen double eiw = lnwage - xbhat - _coef[`one']
    gen double bmills = _b[`mills'] * `mills'
    corr lnwage xbhat eiw bmills
    matrix accum corr`infrm'`yr'sec`sec'`regname' = lnwage xbhat eiw bmills, nocons dev means(corr`infrm'`yr'sec`sec'`regname'_means)
    matrix corr`infrm'`yr'sec`sec'`regname'_sdev = corr`infrm'`yr'sec`sec'`regname'_means
    local j 0
    foreach var in lnwage xbhat eiw bmills {
        local j = `j' + 1
        qui summ `var'
        local entry = int(`r(sd)'*10000)/10000
        matrix corr`infrm'`yr'sec`sec'`regname'_sdev[1,`j']=`entry'
        }
    matrix corr`infrm'`yr'sec`sec'`regname'_tbl = corr(corr`infrm'`yr'sec`sec'`regname')
    matrix corr`infrm'`yr'sec`sec'`regname'_tbl = corr`infrm'`yr'sec`sec'`regname'_sdev ' , corr`infrm'`yr'sec`sec'`regname'_tbl
    matrix corr`infrm'`yr'sec`sec'`regname'_tbl = corr`infrm'`yr'sec`sec'`regname'_means ' , corr`infrm'`yr'sec`sec'`regname'_tbl
    matname corr`infrm'`yr'sec`sec'`regname'_tbl mean sdev, columns(1..2) explicit
    drop xbhat psihat eiw bmills
end

capture program drop corrxttab
program define corrxttab
    args regname yr sec infrm one mills
    predict double xbhat if e(sample)
    replace xbhat = xbhat - _coef[_cons]
    predict double psihat, u
    replace psihat = psihat + _coef[_cons]
    predict double eiw, e
    gen double bmills = _b[`mills'] * `mills'
    corr lnwage xbhat psihat eiw bmills
    matrix accum corr`infrm'`yr'sec`sec'`regname' = lnwage xbhat psihat eiw bmills, nocons dev means(corr`infrm'`yr'sec`sec'`regname'_means)
    matrix corr`infrm'`yr'sec`sec'`regname'_sdev = corr`infrm'`yr'sec`sec'`regname'_means
    local j 0
    foreach var in lnwage xbhat psihat eiw bmills {
        local j = `j' + 1
        qui summ `var'
        local entry = int(`r(sd)'*10000)/10000
        matrix corr`infrm'`yr'sec`sec'`regname'_sdev[1,`j']=`entry'
        }
    matrix corr`infrm'`yr'sec`sec'`regname'_tbl = corr(corr`infrm'`yr'sec`sec'`regname')
    matrix corr`infrm'`yr'sec`sec'`regname'_tbl = corr`infrm'`yr'sec`sec'`regname'_sdev ' , corr`infrm'`yr'sec`sec'`regname'_tbl
    matrix corr`infrm'`yr'sec`sec'`regname'_tbl = corr`infrm'`yr'sec`sec'`regname'_means ' , corr`infrm'`yr'sec`sec'`regname'_tbl
    matname corr`infrm'`yr'sec`sec'`regname'_tbl mean sdev, columns(1..2) explicit
    drop xbhat psihat eiw bmills
end

* Set regression variables
* global selvars "potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8"
global selvars   "potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indblu indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8 fem_indblue"
local seldep "indselct"
local selind "$selvars"
local dep "lnwage"
local indblu "potexper potxper2 potxper3 potxper4 indprim indhigh indscoll                         indblue indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indprim fem_indhigh fem_indscoll                                     fem_indblue"
local indedu "potexper potxper2 potxper3 potxper4 indprim indhigh indscoll indprof indtech indwhit indsklb indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indprim fem_indhigh fem_indscoll fem_indprof fem_indtech fem_indwhit fem_indsklb"
local constan ""

* Set options for Heckman
local if ""
local in ""
local options "twostep"
local twostep "twostep"
local wgt ""
local seloff ""
local off ""
local cluster ""
local rhometh 2     
local rhosigm "rhosigma"
local level $S_level
local if0 `if'          /* Required with second -syntax- */
local in0 `in'
local option0 `options'
local nc `constan'

*YR forvalues yr = 90/98 {}  /* 90/98 */
foreach yr in 90 97 {  /* 90 97 */
tempfile pnadinf

    /* PERFORM HECKMAN ON PNAD SAMPLE */
    /* ------------------------------ */

    use "brazempl/pnad/use-pnad-`yr'", clear
    preserve
      keep if indinfrm==1
      sort worker
      compress
      save `pnadinf'
    restore
    varprep `sec' `yr'
    local lvmills "millspnad"

    /* Define sample */
    local touse "_touse"
    local rtouse "_rtouse"
    mark `touse' `if0' `in0' `wgt'
    markout `touse' `seldep' `selind' `seloff' `cluster', strok
    qui gen byte `rtouse' = `touse'
    markout `rtouse' `dep' `indblu' `off'
    qui replace `touse' = 0  if `seldep' & !`rtouse'

    /* Remove collinearity */
    _rmcoll `selind' if `touse', `selnc'
    local selind "`r(varlist)'"
    _rmdcoll `dep' `indblu' if `touse' & `seldep', `nc'
    local ind "`r(varlist)'"

    /* Do heckman's two-step procedure */
    tempname b0
    tempname bprb breg sigma lnsigma rho rho1 athrho Vprb deltbar wtobs
    tempvar pxb delthat mills

        /* First-step -- probit */
        qui probit `seldep' `selind' `wgt' if `touse', asis `selnc' `seloffo'
        matrix `Vprb' = get(VCE)
        predict double `pxb', xb, if `touse'
        mat `bprb' = get(_b)
        gen double `mills' = normd(`pxb') / normprob(`pxb') 
        local prbll = e(ll)  /* Scalar r(prbll) in original */
        local chi2prb = e(chi2)
        local dfmprbt = e(df_m)
        local r2p = e(r2_p)

        /* Regression strictly to test indep */
        if "`off'" != ""  { 
            local origdep `dep'
            tempname dep
            gen double `dep' = `origdep' - `off'
        }
        if "`wtype'" == "aweight" {
            tempvar wt
            gen double `wt' `wtexp'
            sum `wt' if `touse', meanonly
            replace `wt' = `wt' * r(N) / r(sum)
            sum `wt' if `touse' & `seldep'
            scalar `wtobs' = r(sum)         
                            /* required, e(N) is rounded */
            qui regress `dep' `indblu' [iweight=`wt'], `nc', /*
                */ if `touse' & `seldep'
        }
        else { 
            qui regress `dep' `indblu' `wgt', `nc', if `touse' & `seldep' 
            scalar `wtobs' = e(N)
        }
        local regll = -0.5 * `wtobs' * /*
            */ ( ln(2*_pi) + ln(e(rss)/`wtobs') + 1 )
            /* Scalar r(regll) in original */

        /* Compute delta-bar */
        gen double `delthat' = `mills' * (`mills' + `pxb')
        sum `delthat' if `touse' & `seldep', meanonly
        scalar `deltbar' = r(mean)

        /* Second-step -- regression w/ Mills */
        if "`nc'" == "" {
            tempvar one
            gen byte `one' = 1
        }
        if "`lvmills'" != "" { 
            rename `mills' `lvmills'
            local mills `lvmills'
            label var `mills' "Nonselection hazard"
        }
        qui regress `dep' `indblu' `one' `mills' `wgt', nocons, /*
            */ if `touse' & `seldep'
        corrtab blu `yr' `sec' pnad `one' `mills'
        mat `breg' = get(_b)

        /* Heckman's two-step consistent 
         * estimates of sigma and rho */
        tempname rss ebar adj ratio
        if e(rss) == . {
            tempvar e
            predict double `e' if `touse', resid
            replace `e' = sum(`e'^2)
            scalar `rss' = `e'[_N]
            if `rss' == . {
                error 1400
            }
        }
        else    scalar `rss' = e(rss)
        
        scalar `ebar' = `rss' / e(N)
        scalar `sigma' = sqrt(`ebar' + `deltbar'*_b[`mills']^2)

        scalar `rho' = _b[`mills'] / `sigma'
        scalar `rho1' = `rho'
        if abs(`rho') > 1 & `rhometh' >= 1 & `rhometh' <= 2 {
            scalar `rho' = `rho'/abs(`rho')
            noi di in blue "note: two-step estimate " /*
              */ "of rho = "  `rho1' " is being "        /*
              */ "truncated to " `rho'
            if `rhometh' == 2 {
                scalar `sigma' = _b[`mills']*`rho'
            }
        }
        if `sigma' == 0 {scalar `sigma' = .001}
        if `rho' == . { scalar `rho' = 0 }

        noi Heck2 `breg' `rho' `sigma' `bprb' `Vprb' `dep' /*
            */ "`indblu'" "`nc'" "`seldep'" "`selind'"    /*
            */ "`selnc'" "`mills'" "`delthat'"     /*
            */ "`touse'" "`rhometh'" "`rho1'"

        /* Report heckman's two-step procedure */
        Display2 `dep' `seldep' `rhotrunc'`rhosigmafix'`rhoforce'`rholimited' `touse', level(`level')
        drop _*
        label var millspnad "Nonselection hazard PNAD"
        est2vec wage`infrm'`yr'sec`sec', replace vars(lnwage:potexper lnwage:potxper2 lnwage:potxper3 lnwage:potxper4 lnwage:tenuryr lnwage:tenr2 lnwage:tenr3 lnwage:tenr4 lnwage:indschlg1 lnwage:indschlg2 lnwage:indschlg3 lnwage:indschlg4 lnwage:indschlg5 lnwage:indschlg6 lnwage:indschlg7 lnwage:indschlg8 lnwage:indprim lnwage:indhigh lnwage:indprim_alt lnwage:indhigh_alt lnwage:indscoll lnwage:indgrad lnwage:indprof lnwage:indtech lnwage:indwhit lnwage:indsklb lnwage:indunsklb lnwage:indblue lnwage:indfem lnwage:fem_potexper lnwage:fem_potxper2 lnwage:fem_potxper3 lnwage:fem_potxper4 lnwage:fem_tenuryr lnwage:fem_tenr2 lnwage:fem_tenr3 lnwage:fem_tenr4 lnwage:fem_indschlg1 lnwage:fem_indschlg2 lnwage:fem_indschlg3 lnwage:fem_indschlg4 lnwage:fem_indschlg5 lnwage:fem_indschlg6 lnwage:fem_indschlg7 lnwage:fem_indschlg8 lnwage:fem_indprim lnwage:fem_indhigh lnwage:fem_indprim_alt lnwage:fem_indhigh_alt lnwage:fem_indscoll lnwage:fem_indgrad lnwage:fem_indprof lnwage:fem_indtech lnwage:fem_indwhit lnwage:fem_indsklb lnwage:fem_indunsklb lnwage:fem_indblue lnwage:_cons indselct:potexper indselct:potxper2 indselct:potxper3 indselct:potxper4 indselct:indschlg1 indselct:indschlg2 indselct:indschlg3 indselct:indschlg4 indselct:indschlg5 indselct:indschlg6 indselct:indschlg7 indselct:indschlg8 indselct:indprof indselct:indtech indselct:indwhit indselct:indsklb indselct:indblue indselct:indfem indselct:fem_potexper indselct:fem_potxper2 indselct:fem_potxper3 indselct:fem_potxper4 indselct:fem_indschlg1 indselct:fem_indschlg2 indselct:fem_indschlg3 indselct:fem_indschlg4 indselct:fem_indschlg5 indselct:fem_indschlg6 indselct:fem_indschlg7 indselct:fem_indschlg8 indselct:fem_indprof indselct:fem_indtech indselct:fem_indwhit indselct:fem_indsklb indselct:fem_indblue indselct:_cons mills:lambda) e(N N_cens chi2 chi2_c p p_c df_m rho sigma lambda selambda) name(yr`yr'sec`sec'blupnad)
        mat wage`infrm'`yr'sec`sec'_r = `chi2prb' \ `dfmprbt' \ `r2p'
        matname wage`infrm'`yr'sec`sec'_r r(chi2) r(df_m) r(r2_p), rows(1..3) explicit
        matname wage`infrm'`yr'sec`sec'_r yr`yr'sec`sec'blupnad, columns(1) explicit


    /* PERFORM HECKMAN 2-ND STAGE ON RAIS SAMPLE */
    /* ----------------------------------------- */

   foreach data in blu edu {
   foreach regr in reg xtreg {   

   if "`regr'"=="reg" {
     local corrtab = "corrtab"
     local prdopt "res"
     local regopt "nocons"
     }
   if "`regr'"=="xtreg" {
     local corrtab = "corrxttab"
     local prdopt "e"
     local regopt "fe"
     }

    /* Out-of-Sample predicted inverse Mills ratios */
    use if sector==`sec' using "brazempl/use-brazempl-`yr'", clear
    gen byte indinfrm = 0
    gen byte indblue = (indprof==0 & indtech==0 & indwhit==0)
    label var indblue "Blue-collar occupation"
    append using `pnadinf'
    varprep `sec' `yr'
    local mills "millsrais"
    local pxb "pxbrais"
    iis plant

    * Out-of-sample prediction of Mills ratios
      qui _predict double `pxb', eq(#2)
      qui gen double `mills' = normd(`pxb') / normprob(`pxb')
      label var `pxb' "Probit prediction RAIS"
      label var `mills' "Nonselection hazard RAIS"

    /* Define sample */
    local touse "_touse"
    local rtouse "_rtouse"
    mark `touse' `if0' `in0' `wgt'
    markout `touse' `seldep' `selind' `seloff' `cluster', strok
    qui gen byte `rtouse' = `touse'
    markout `rtouse' `dep' `ind`data'' `off'
    qui replace `touse' = 0  if `seldep' & !`rtouse'

    /* Remove collinearity */
    _rmcoll `selind' if `touse', `selnc'
    local selind "`r(varlist)'"
    _rmdcoll `dep' `ind`data'' if `touse' & `seldep', `nc'
    local ind "`r(varlist)'"

    /* Do heckman's two-step procedure */
    tempname b0
    tempname breg sigma lnsigma rho rho1 athrho deltbar wtobs
    tempvar delthat

        /* First-step -- probit; Reuse PNAD estimates */
        qui matrix list `Vprb'
        qui matrix list `bprb'
        disp "prbll: `prbll'"  /* Scalar r(prbll) in original */

        /* Compute delta-bar */
        gen double `delthat' = `mills' * (`mills' + `pxb')
        sum `delthat' if `touse' & `seldep', meanonly
        scalar `deltbar' = r(mean)

        /* Second-step -- regression w/ Mills */
        if "`nc'" == "" {
            tempvar one
            gen byte `one' = 1
        }
        qui `regr' `dep' `ind`data'' `one' `mills' `wgt', `regopt', if `touse' & `seldep'
        `corrtab' `data' `yr' `sec' `regr' `one' `mills'

        mat `breg' = get(_b)
        if "`e(cmd)'"=="xtreg" {  /* Exchange estimate on `one' for _cons */
          local colsxt = colsof(`breg')
          mat `breg'[1,`colsxt'-2] = `breg'[1,`colsxt']
          mat `breg' = `breg'[1,1..`colsxt'-1]
          mat list `breg'
          }
        disp "e(rmse)^2: " e(rmse)^2

        /* Heckman's two-step consistent 
         * estimates of sigma and rho */
        tempname rss ebar adj ratio
        if e(rss) == . {
            tempvar e
            predict double `e' if `touse', `prdopt'
            replace `e' = sum(`e'^2)
            scalar `rss' = `e'[_N]
            if `rss' == . {
                error 1400
            }
        }
        else    scalar `rss' = e(rss)
        
        scalar `ebar' = `rss' / e(N)
        scalar `sigma' = sqrt(`ebar' + `deltbar'*_b[`mills']^2)

        scalar `rho' = _b[`mills'] / `sigma'
        scalar `rho1' = `rho'
        if abs(`rho') > 1 & `rhometh' >= 1 & `rhometh' <= 2 {
            scalar `rho' = `rho'/abs(`rho')
            noi di in blue "note: two-step estimate " /*
              */ "of rho = "  `rho1' " is being "        /*
              */ "truncated to " `rho'
            if `rhometh' == 2 {
                scalar `sigma' = _b[`mills']*`rho'
            }
        }
        if `sigma' == 0 {scalar `sigma' = .001}
        if `rho' == . { scalar `rho' = 0 }

        noi Heck2 `breg' `rho' `sigma' `bprb' `Vprb' `dep' /*
            */ "`ind`data''" "`nc'" "`seldep'" "`selind'"    /*
            */ "`selnc'" "`mills'" "`delthat'"     /*
            */ "`touse'" "`rhometh'" "`rho1'"

        /* Report heckman's two-step procedure */
        Display2 `dep' `seldep' `rhotrunc'`rhosigmafix'`rhoforce'`rholimited' `touse', level(`level')
        drop _*
        label var millsrais "Nonselection hazard PNAD"
        est2vec wage`infrm'`yr'sec`sec', addto(wage`infrm'`yr'sec`sec') name(yr`yr'sec`sec'`data'`regr')
        est2vec wage`infrm'`yr'sec`sec', raddto(wage`infrm'`yr'sec`sec') name(yr`yr'sec`sec'`data'`regr')
        }
      }

local regr pnad 
local data blu
est2tex corr`regr'`yr'sec`sec'`data', replace dropall preserve ready digits(4) fancy path(brazempl/tex/heckman/corr)
foreach regr in reg xtreg {
  foreach data in blu edu {
  est2tex corr`regr'`yr'sec`sec'`data', replace dropall preserve ready digits(4) fancy path(brazempl/tex/heckman/corr)
  }
}
est2tex wageheckman`yr'sec`sec', replace dropall preserve mark(it) digits(4) fancy path(brazempl/tex/heckman/wage) label
}

log close
cd "$home"
